@@ -1,11 +1,11 @@
 package Net::DNS::SEC;
 
 #
-# $Id: SEC.pm 1702 2018-07-28 07:39:01Z willem $
+# $Id: SEC.pm 1704 2018-08-13 08:30:50Z willem $
 #
 our $VERSION;
-$VERSION = '1.09_01';
-our $SVNVERSION = (qw$LastChangedRevision: 1702 $)[1];
+$VERSION = '1.09_02';
+our $SVNVERSION = (qw$LastChangedRevision: 1704 $)[1];
 our $XS_VERSION = $VERSION;
 $VERSION = eval($VERSION);
 
@@ -21,12 +21,13 @@ Net::DNS::SEC - DNSSEC extensions to Net::DNS
 =head1 DESCRIPTION
 
 Net::DNS::SEC is installed as an extension to an existing Net::DNS
-installation providing additional packages to support DNSSEC as
-described in RFC4033, RFC4034, RFC4035 and related documents.
+installation providing packages to support DNSSEC as specified in
+RFC4033, RFC4034, RFC4035 and related documents.
 
 It also provides support for SIG0 which is useful for dynamic updates.
 
-RSA, DSA, ECDSA, and Edwards curve crypto algorithms are supported.
+Implements cryptographic signature generation and verification functions
+using RSA, DSA, ECDSA, and Edwards curve algorithms.
 
 The extended features are made available by replacing Net::DNS by
 Net::DNS::SEC in the use declaration.
